pub struct Crawler<PeerSet, Mempool> {
peer_set: Timeout<PeerSet>,
mempool: Mempool,
sync_status: SyncStatus,
chain_tip_change: ChainTipChange,
debug_enable_at_height: Option<Height>,
}Expand description
The mempool transaction crawler.
Fields
peer_set: Timeout<PeerSet>The network peer set to crawl.
mempool: MempoolThe mempool service that receives crawled transaction IDs.
sync_status: SyncStatusAllows checking if we are near the tip to enable/disable the mempool crawler.
chain_tip_change: ChainTipChangeNotifies the crawler when the best chain tip height changes.
debug_enable_at_height: Option<Height>If the state’s best chain tip has reached this height, always enable the mempool crawler.
Implementations
Sourceimpl<PeerSet, Mempool> Crawler<PeerSet, Mempool>
impl<PeerSet, Mempool> Crawler<PeerSet, Mempool>
Sourcepub fn spawn(
config: &Config,
peer_set: PeerSet,
mempool: Mempool,
sync_status: SyncStatus,
chain_tip_change: ChainTipChange,
) -> JoinHandle<Result<(), BoxError>>
pub fn spawn( config: &Config, peer_set: PeerSet, mempool: Mempool, sync_status: SyncStatus, chain_tip_change: ChainTipChange, ) -> JoinHandle<Result<(), BoxError>>
Spawn an asynchronous task to run the mempool crawler.
Sourceasync fn wait_until_enabled_by_debug(&mut self) -> Result<(), RecvError>
async fn wait_until_enabled_by_debug(&mut self) -> Result<(), RecvError>
Waits until the mempool crawler is enabled by a debug config option.
Returns an error if communication with the state is lost.
Sourceasync fn wait_until_enabled(&mut self) -> Result<(), RecvError>
async fn wait_until_enabled(&mut self) -> Result<(), RecvError>
Waits until the mempool crawler is enabled.
Returns an error if communication with the syncer or state is lost.
Sourcepub async fn run(self) -> Result<(), BoxError>
pub async fn run(self) -> Result<(), BoxError>
Periodically crawl peers for transactions to include in the mempool.
Runs until the SyncStatus loses its connection to the chain syncer, which happens when
Zebra is shutting down.
Sourceasync fn crawl_transactions(&mut self) -> Result<(), BoxError>
async fn crawl_transactions(&mut self) -> Result<(), BoxError>
Crawl peers for transactions.
Concurrently request FANOUT peers for transactions to include in the mempool.
Sourceasync fn handle_response(&mut self, response: Response) -> Result<(), BoxError>
async fn handle_response(&mut self, response: Response) -> Result<(), BoxError>
Handle a peer’s response to the crawler’s request for transactions.
Sourceasync fn queue_transactions(
&mut self,
transaction_ids: HashSet<UnminedTxId>,
) -> Result<(), BoxError>
async fn queue_transactions( &mut self, transaction_ids: HashSet<UnminedTxId>, ) -> Result<(), BoxError>
Forward the crawled transactions IDs to the mempool transaction downloader.